==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/ru/lang.php <==
<?php
/**
 * Russian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Denis Simakov <akinoame1@gmail.com>
 * @author Змей Этерийский evil_snake@eternion.ru
 * @author Hikaru Nakajima <jisatsu@mail.ru>
 * @author Alexei Tereschenko <alexeitlex@yahoo.com>
 */
$lang['admin_acl']             = 'Управление списками контроля доступа';
$lang['acl_group']             = 'Группа';
$lang['acl_user']              = 'Пользователь';
$lang['acl_perms']             = 'Права доступа для';
$lang['page']                  = 'Страница';
$lang['namespace']             = 'Пространство имен';
$lang['btn_select']            = 'Выбрать';
$lang['p_user_id']             = 'Сейчас пользователь <b class="acluser">%s</b> имеет следующие права на доступ к странице <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Сейчас пользователь <b class="acluser">%s</b> имеет следующие права на доступ к пространству имён <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Сейчас члены группы <b class="aclgroup">%s</b> имеют следующие права на доступ к странице <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Сейчас члены группы <b class="aclgroup">%s</b> cимеют следующие права на доступ к пространству имён <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Пожалуйста, <b>введите пользователя или группу</b> в форме выше, чтобы просмотреть или отредактировать права на доступ к странице <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Пожалуйста, <b>введите пользователя или группу</b> в форме выше, чтобы просмотреть или отредактировать права на доступ к пространству имён <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Замечание: Эти права доступа не были заданы явно, а были унаследованы от других групп или пространств имён более высокого порядка.';
$lang['p_isadmin']             = 'Замечание: Выбранный пользователь всегда имеет полные права так, как он является суперпользователем.';
$lang['p_include']             = 'Более высокие права доступа включают в себя более низкие. Права доступа Создание, Загрузка и Удаление относятся только к пространствам имён, а не к страницам.';
$lang['current']               = 'Текущие права ACL';
$lang['where']                 = 'Страница/Пространство имён';
$lang['who']                   = 'Пользователь/Группа';
$lang['perm']                  = 'Права доступа';
$lang['acl_perm0']             = 'Замечание';
$lang['acl_perm1']             = 'Чтение';
$lang['acl_perm2']             = 'Правка';
$lang['acl_perm4']             = 'Создание';
$lang['acl_perm8']             = 'Загрузка файлов';
$lang['acl_perm16']            = 'Удаление';
$lang['acl_new']               = 'Добавить новую запись';
$lang['acl_mod']               = 'Отредактировать запись';

==> dokuwiki_0.0.20120125b.orig.tar.gz: dokuwiki-2012-01-25b/lib/plugins/acl/lang/ru/lang.php <==
<?php
/**
 * Russian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Denis Simakov <akinoame1@gmail.com>
 * @author Змей Этерийский evil_snake@eternion.ru
 * @author Hikaru Nakajima <jisatsu@mail.ru>
 * @author Alexei Tereschenko <alexeitlex@yahoo.com>
 * @author Irina Ponomareva irinaponomareva@webperfectionist.com
 * @author Alexander Sorkin <kibizoid@gmail.com>
 * @author Kirill Krasnov <krasnovforum@gmail.com>
 * @author Vlad Tsybenko <vlad.development@gmail.com>
 * @author Aleksey Osadchiy <rfc@nm.ru>
 * @author Aleksandr Selivanov <alexgearbox@gmail.com>
 * @author Ladyko Andrey <fylh@succexy.spb.ru>
 * @author Eugene <windy.wanderer@gmail.com>
 */
$lang['admin_acl']             = 'Управление списками контроля доступа';
$lang['acl_group']             = 'Группа';
$lang['acl_user']              = 'Пользователь';
$lang['acl_perms']             = 'Права доступа для';
$lang['page']                  = 'Страница';
$lang['namespace']             = 'Пространство имён';
$lang['btn_select']            = 'Выбрать';
$lang['p_user_id']             = 'Сейчас пользователь <b class="acluser">%s</b> имеет следующие права на доступ к странице <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Сейчас пользователь <b class="acluser">%s</b> имеет следующие права на доступ к пространству имён <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Сейчас члены группы <b class="aclgroup">%s</b> имеют следующие права на доступ к странице <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Сейчас члены группы <b class="aclgroup">%s</b> cимеют следующие права на доступ к пространству имён <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Пожалуйста, <b>введите пользователя или группу</b> в форме выше, чтобы просмотреть или отредактировать права на доступ к странице <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Пожалуйста, <b>введите пользователя или группу</b> в форме выше, чтобы просмотреть или отредактировать права на доступ к пространству имён <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Замечание: эти права доступа не были заданы явно, а были унаследованы от других групп или пространств имён более высокого порядка.';
$lang['p_isadmin']             = 'Замечание: выбранный пользователь всегда имеет полные права, так как он является суперпользователем.';
$lang['p_include']             = 'Более высокие права доступа включают в себя более низкие. Права доступа «Создание», «Загрузка» и «Удаление» относятся только к пространствам имён, а не к страницам.';
$lang['current']               = 'Текущие права ACL';
$lang['where']                 = 'Страница/Пространство имён';
$lang['who']                   = 'Пользователь/Группа';
$lang['perm']                  = 'Права доступа';
$lang['acl_perm0']             = 'Нет доступа';
$lang['acl_perm1']             = 'Чтение';
$lang['acl_perm2']             = 'Правка';
$lang['acl_perm4']             = 'Создание';
$lang['acl_perm8']             = 'Загрузка файлов';
$lang['acl_perm16']            = 'Удаление';
$lang['acl_new']               = 'Добавить новую запись';
$lang['acl_mod']               = 'Отредактировать запись';
